package com.weilab.biology.core.data.enums;

import lombok.Getter;

import java.util.HashMap;
import java.util.Map;

/**
 * 任务状态的枚举类
 */
@Getter
public enum JobStatusEnum {
    /**
     * 等待运行
     */
    WAITING(0, "waiting"),
    /**
     * 正在运行
     */
    RUNNING(1, "running"),
    /**
     * 任务执行成功
     */
    SUCCESS(2, "success"),
    /**
     * 已发送请求
     */
    REQED(3, "requested"),
    /**
     * 任务执行失败
     */
    FAIL(-1, "failed"),
    /**
     * 运行超时
     */
    TIMEOUT(-2, "timeout"),
    /**
     * 正在创建
     */
    CREATING(-3, "creating"),
    ;

    private final Integer key;
    private final String remark;

    private final static Map<Integer, JobStatusEnum> HOLDER = new HashMap<>();

    static {
        for (JobStatusEnum e : JobStatusEnum.values()) {
            HOLDER.put(e.key, e);
        }
    }

    private JobStatusEnum(Integer key, String remark) {
        this.key = key;
        this.remark = remark;
    }

    public static String getRemark(Integer key) {
        return HOLDER.get(key).remark;
    }

    public static JobStatusEnum getEnumByKey(Integer key) {
        return HOLDER.get(key);
    }

}
